==> jc-1.4.0.tar.gz: javax/swing/UIDefaults__24LazyInputMap.h <==
// public class javax.swing.UIDefaults$LazyInputMap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c3f1560bab848bf5 javax_swing_UIDefaults__24LazyInputMap

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIDefaults__24LazyInputMap_H_
#define _JC_javax_swing_UIDefaults__24LazyInputMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_UIDefaults$object;

// Typedefs
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$sub_refs	_jc_javax_swing_UIDefaults__24LazyInputMap$sub_refs;
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$sub_nonrefs	_jc_javax_swing_UIDefaults__24LazyInputMap$sub_nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$refs	_jc_javax_swing_UIDefaults__24LazyInputMap$refs;
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$nonrefs	_jc_javax_swing_UIDefaults__24LazyInputMap$nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$object	_jc_javax_swing_UIDefaults__24LazyInputMap$object;

typedef const struct _jc_javax_swing_UIDefaults__24LazyInputMap$vmethods	_jc_javax_swing_UIDefaults__24LazyInputMap$vmethods;
typedef const struct _jc_javax_swing_UIDefaults__24LazyInputMap$vtable	_jc_javax_swing_UIDefaults__24LazyInputMap$vtable;
typedef const struct _jc_javax_swing_UIDefaults__24LazyInputMap$vtype	_jc_javax_swing_UIDefaults__24LazyInputMap$vtype;

// Constructors
extern void _jc_javax_swing_UIDefaults__24LazyInputMap$method$_init$01ab6a5208b30dec(_jc_env *, struct _jc_javax_swing_UIDefaults__24LazyInputMap$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_UIDefaults__24LazyInputMap$method$createValue$5246839c46d82ae8(_jc_env *, struct _jc_javax_swing_UIDefaults__24LazyInputMap$object *, struct _jc_javax_swing_UIDefaults$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIDefaults__24LazyInputMap$method_info$createValue$5246839c46d82ae8;

// Virtual methods structure
struct _jc_javax_swing_UIDefaults__24LazyInputMap$vmethods {
	struct _jc_java_lang_Object$object	*(*createValue$5246839c46d82ae8)(_jc_env *, struct _jc_javax_swing_UIDefaults__24LazyInputMap$object *, struct _jc_javax_swing_UIDefaults$object *);
};

// Vtable
struct _jc_javax_swing_UIDefaults__24LazyInputMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIDefaults__24LazyInputMap$vmethods	javax_swing_UIDefaults__24LazyInputMap;
};

// Vtype
struct _jc_javax_swing_UIDefaults__24LazyInputMap$vtype {
	_jc_type			type;
	_jc_javax_swing_UIDefaults__24LazyInputMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24LazyInputMap$sub_refs {
	_jc_object_array	*bind;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24LazyInputMap$refs {
    _jc_javax_swing_UIDefaults__24LazyInputMap$sub_refs	javax_swing_UIDefaults__24LazyInputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24LazyInputMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24LazyInputMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIDefaults__24LazyInputMap$sub_nonrefs	javax_swing_UIDefaults__24LazyInputMap;
};

// Object instance structure
struct _jc_javax_swing_UIDefaults__24LazyInputMap$object {
	_jc_javax_swing_UIDefaults__24LazyInputMap$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIDefaults__24LazyInputMap$vtype	*vtype;
	_jc_javax_swing_UIDefaults__24LazyInputMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIDefaults__24LazyInputMap$vtype _jc_javax_swing_UIDefaults__24LazyInputMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIDefaults__24LazyInputMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIDefaults__24LazyInputMap$class_object;

#endif	/* _JC_javax_swing_UIDefaults__24LazyInputMap_H_ */

==> jc-1.4.5.tar.gz: javax/swing/UIDefaults__24LazyInputMap.h <==
// public class javax.swing.UIDefaults$LazyInputMap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2b1b023cc2197df3 javax_swing_UIDefaults__24LazyInputMap

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_UIDefaults__24LazyInputMap_H_
#define _JC_javax_swing_UIDefaults__24LazyInputMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_UIDefaults$object;

// Typedefs
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$sub_refs	_jc_javax_swing_UIDefaults__24LazyInputMap$sub_refs;
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$sub_nonrefs	_jc_javax_swing_UIDefaults__24LazyInputMap$sub_nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$refs	_jc_javax_swing_UIDefaults__24LazyInputMap$refs;
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$nonrefs	_jc_javax_swing_UIDefaults__24LazyInputMap$nonrefs;
typedef struct _jc_javax_swing_UIDefaults__24LazyInputMap$object	_jc_javax_swing_UIDefaults__24LazyInputMap$object;

typedef const struct _jc_javax_swing_UIDefaults__24LazyInputMap$vmethods	_jc_javax_swing_UIDefaults__24LazyInputMap$vmethods;
typedef const struct _jc_javax_swing_UIDefaults__24LazyInputMap$vtable	_jc_javax_swing_UIDefaults__24LazyInputMap$vtable;
typedef const struct _jc_javax_swing_UIDefaults__24LazyInputMap$vtype	_jc_javax_swing_UIDefaults__24LazyInputMap$vtype;

// Constructors
extern void _jc_javax_swing_UIDefaults__24LazyInputMap$method$_init$01ab6a5208b30dec(_jc_env *, struct _jc_javax_swing_UIDefaults__24LazyInputMap$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_UIDefaults__24LazyInputMap$method$createValue$5246839c46d82ae8(_jc_env *, struct _jc_javax_swing_UIDefaults__24LazyInputMap$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_UIDefaults__24LazyInputMap$method_info$createValue$5246839c46d82ae8;

// Virtual methods structure
struct _jc_javax_swing_UIDefaults__24LazyInputMap$vmethods {
	struct _jc_java_lang_Object$object	*(*createValue$5246839c46d82ae8)(_jc_env *, struct _jc_javax_swing_UIDefaults__24LazyInputMap$object *, struct _jc_javax_swing_UIDefaults$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_UIDefaults__24LazyInputMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_UIDefaults__24LazyInputMap$vmethods	javax_swing_UIDefaults__24LazyInputMap;
};

// Vtype
struct _jc_javax_swing_UIDefaults__24LazyInputMap$vtype {
	_jc_type			type;
	_jc_javax_swing_UIDefaults__24LazyInputMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24LazyInputMap$sub_refs {
	_jc_object_array	*bind;
};

// Reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24LazyInputMap$refs {
    _jc_javax_swing_UIDefaults__24LazyInputMap$sub_refs	javax_swing_UIDefaults__24LazyInputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_UIDefaults__24LazyInputMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_UIDefaults__24LazyInputMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_UIDefaults__24LazyInputMap$sub_nonrefs	javax_swing_UIDefaults__24LazyInputMap;
};

// Object instance structure
struct _jc_javax_swing_UIDefaults__24LazyInputMap$object {
	_jc_javax_swing_UIDefaults__24LazyInputMap$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_UIDefaults__24LazyInputMap$vtype	*vtype;
	_jc_javax_swing_UIDefaults__24LazyInputMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_UIDefaults__24LazyInputMap$vtype _jc_javax_swing_UIDefaults__24LazyInputMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_UIDefaults__24LazyInputMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_UIDefaults__24LazyInputMap$class_object;

#endif	/* _JC_javax_swing_UIDefaults__24LazyInputMap_H_ */
